require 'minitest/autorun'
require 'minitest/pride'
require 'amazonparser'
require 'vacuum'

class AmazonParserTest < Minitest::Test
  def test_request
    # 1. init vacuum
    request = Vacuum.new('US', true)
    request.configure(
      aws_access_key_id: ENV['AWS_ACCESS_KEY_ID'],
      aws_secret_access_key: ENV['AWS_SECRET_ACCESS_KEY'],
      associate_tag: 'makeuppicker-20',
      version: nil
    )

    # 2. setup request
    query = {
      'ItemId' => 'B000V3MGFS',
      'ResponseGroup' => 'BrowseNodes, Images, ItemAttributes, OfferFull, PromotionSummary, SalesRank'
    }

    # 3. request item
    response = request.item_lookup(query: query, persistent: true)
    response.parser = nil

    # 4. convert xml response to hash
    product_hash = response.parse

    # 5. parse product
    product = AmazonParser.parse(product_hash: product_hash)

    # display output while transforming into tests
    puts "asin: " + product.asin.inspect
    puts "title: " + product.title.inspect
    puts "category: " + product.category.inspect
    puts "brand: " + product.brand.inspect

    puts "list_price: " + product.list_price.inspect
    puts "price: " + product.price.inspect
    puts "sale_price: " + product.sale_price.inspect
    puts "discount: " + product.discount.inspect
    puts "lowest_new_price: " + product.lowest_new_price.inspect
    puts "lowest_used_price: " + product.lowest_used_price.inspect
    puts "new_count: " + product.new_count.inspect
    puts "used_count: " + product.used_count.inspect
    puts "percent_discount: " + product.percent_discount.inspect
    puts "availability_message: " + product.availability_message.inspect
    puts "availability_type: " + product.availability_type.inspect
    puts "min_hours_until_available: " + product.min_hours_until_available.inspect
    puts "max_hours_until_available: " + product.max_hours_until_available.inspect
    puts "has_super_saver_shipping: " + product.has_super_saver_shipping.inspect
    puts "has_prime: " + product.has_prime.inspect

    puts "color: " + product.color.inspect
    puts "size: " + product.size.inspect
    puts "package_quantity: " + product.package_quantity.inspect
    puts "part_number: " + product.part_number.inspect
    puts "group: " + product.group.inspect
    puts "manufacturer: " + product.manufacturer.inspect
    puts "release_date: " + product.release_date.inspect
    puts "number_of_items: " + product.number_of_items.inspect
    puts "publisher: " + product.publisher.inspect
    puts "product_type_name: " + product.type.inspect
  end
end
